@@ -5,6 +5,7 @@
 
 require "rbconfig"
 require "pathname"
+require "time"
 
 ruby = File.join(RbConfig::CONFIG['bindir'],
                  RbConfig::CONFIG['RUBY_INSTALL_NAME'] + RbConfig::CONFIG['EXEEXT'])
@@ -28,24 +29,28 @@ Pathname.glob((base_dir + "*").to_s) do |dir|
 end
 
 ignored_modules = [
-  "gdk_pixbuf2-no-gi",
-  "gstreamer-no-gi",
-  "gdk3-no-gi",
-  "gtk3-no-gi",
-  "gtksourceview3-no-gi",
-  "vte3-no-gi",
 ]
 
 failed_target_names = []
 targets.each do |target|
+  next if target.basename.to_s.end_with?("-no-gi")
   next if ignored_modules.include?(target.basename.to_s)
   Dir.chdir(target.to_s) do
-    puts "#{Time.now} running test for #{target}"
+    puts "#{Time.now.iso8601}: Running test for #{target}"
     puts separator
 
-    args = includes + ["test/run-test.rb"]
-    command = [ruby, *args]
-    unless system(command.collect {|arg| "'#{arg.gsub(/'/, '\\\'')}'"}.join(' '))
+    dependency_check = "dependency-check/Rakefile"
+    if File.exist?(dependency_check)
+      unless system(ruby, *includes, "-S",
+                    "rake", "--rakefile", dependency_check)
+        puts "Failed to resolve dependency: #{target.basename}"
+        puts separator
+        next
+      end
+    end
+
+    unless system(ruby, *includes, "test/run-test.rb")
+      puts "Failed to run test: #{target.basename}"
       failed_target_names << target.basename.to_s
     end
 
